def plot_residuals(actuals, predictions) -> None: ...
def plot_actual_vs_predicted(actuals, predictions) -> None: ...
def plot_error_distribution(errors) -> None: ...
def calculate_metrics(dataloader, model): ...
